Exception: JSON::LD::ProcessingError
- Inherits:
-
Exception
- Object
- Exception
- JSON::LD::ProcessingError
- Defined in:
- lib/json/ld.rb
Direct Known Subclasses
Defined Under Namespace
Classes: Conflict, LanguageMap, ListOfLists, Lossy
Constant Summary collapse
- LOSSY_COMPACTION =
The compaction would lead to a loss of information, such as a @language value.
1- CONFLICTING_DATATYPES =
The target datatype specified in the coercion rule and the datatype for the typed literal do not match.
2- LIST_OF_LISTS_DETECTED =
A list containing another list was detected.
3- ILLEGAL_LANGUAGE_MAP_DETECTED =
When processing a language map, a value not a
4
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
Returns the value of attribute code.
Instance Attribute Details
#code ⇒ Object (readonly)
Returns the value of attribute code.
95 96 97 |
# File 'lib/json/ld.rb', line 95 def code @code end |